@@ -145,7 +145,7 @@ where m.headerMessageID==(?)"""
         return m       
                 
     
-__version__ = "0.0.7"
+__version__ = "0.0.8"
 __date__ = '2021-09-23'
 __updated__ = '2021-09-23'    
 
@@ -188,8 +188,11 @@ USAGE
   
         # Process arguments
         args = parser.parse_args(argv)
-        mail=Mail(user=args.user,mailid=args.id,debug=args.debug)
-        print (mail.msg)
+        if args.user is None or args.id is None:
+            parser.print_help()
+        else:
+            mail=Mail(user=args.user,mailid=args.id,debug=args.debug)
+            print (mail.msg)
 
     except KeyboardInterrupt:
         ### handle keyboard interrupt ###
